import java.io.*;
import java.util.*;
import java.util.function.*;
import java.util.concurrent.atomic.*;
import java.util.concurrent.*;

/**
 * @author Georgiy Korneev (kgeorgiy@kgeorgiy.info)
 */
public class Tests {
    private static final int MIN_N = 1;
    private static final int MAX_N = 1_000_000_000;
    private static final int MIN_M = 500;
    private static final int MAX_M = 11_299;
    private static final int MIN_C = 169;
    private static final int MAX_C = 220;

    private int tests = 1;
    private final SplittableRandom RANDOM = new SplittableRandom(4875080234878438422L);
    private final SplittableRandom random;

    private Tests() {
        random = RANDOM.split();
    }

    public void test(final int n, final int m, final int c) {
        System.out.format("    %10d %5d %3d = %5d %s%n", n, m, c, OK.solve(n, m, c), fails(n, m, c));
        try (PrintWriter out = new PrintWriter(String.format("%02d", tests++))) {
            out.println(n);
            out.println(m);
            out.println(c);
        } catch (IOException e) {
            throw new UncheckedIOException(e);
        }
    }

    private int randomInt(final int min, final int max) {
        return random.nextInt(max - min + 1) + min;
    }

    private static class Solution {
        private final IntUnaryOperator opM;
        private final Function<Double, Long> opC;

        public Solution(final IntUnaryOperator opM, final Function<Double, Long> opC) {
            this.opM = opM;
            this.opC = opC;
        }

        public int solve(final int n, final int m, final int c) {
            int best = n;
            int mBound = opM.applyAsInt(n / m);
            for (int M = 0; M <= mBound; M++) {
                int C = opC.apply((n - m * M) / (double) c).intValue();
                best = Math.min(best, Math.abs(m * M + c * C - n));
            }
            return best;
        }
    }

    private static final Solution OK = 
                         new Solution(M -> M + 1, C -> Math.max(0,        Math.round(C)));
    private static final Map<String, Solution> WA = new HashMap<>();
    static {
        WA.put("neg"   , new Solution(M -> M + 1, C ->                    Math.round(C) ));
        WA.put("floor" , new Solution(M -> M + 1, C -> Math.max(0, (long) Math.floor(C))));
        WA.put("ceil"  , new Solution(M -> M + 1, C -> Math.max(0, (long) Math.ceil (C))));
        WA.put("div"   , new Solution(M -> M    , C -> Math.max(0,        Math.round(C))));
    }

    private Set<String> fails(final int n, final int m, final int c) {
        final Set<String> fails = new TreeSet<>();
        final int answer =  OK.solve(n, m, c);
        for (final Map.Entry<String, Solution> entry : WA.entrySet()) {
            if (entry.getValue().solve(n, m, c) != answer) {
                fails.add(entry.getKey());
            }
        }
        return fails;
    }

    private AtomicInteger i = new AtomicInteger();
    private AtomicInteger n = new AtomicInteger(MIN_N);
    private final Set<Set<String>> known = Collections.newSetFromMap(new ConcurrentHashMap<>());

    private void search() {
        int maxFails = -1;
        int bestN = 0;
        int bestM = 0;
        int bestC = 0;
//        final Set<Set<String>> known = new HashSet<>();

        while (true) {
            int n = this.n.getAndIncrement();
            if (n % 10_000 == 0) {
                System.err.println(n);
            }

            for (int q = 0; q < 100; q++) {
                final int m = randomInt(MIN_M, MAX_M);
  //          for (int m = MIN_M; m <= MAX_M; m++) {
                for (int c = MIN_C; c <= MAX_C; c++) {
//            final int m = randomInt(MIN_M, MAX_M);
//            final int c = randomInt(MIN_C, MAX_C);
//            
//            for (int q = 0; q < 1; q++) {
//                int n;
//                if (false && random.nextBoolean()) {
//                    final int M = randomInt(0, MAX_N / 2 / m);
//                    final int C = randomInt(0, MAX_N / 2 / c);
//                    n = M * m + C * c + randomInt(-c / 4, c / 4);
//                } else {
//                    n = randomInt(MIN_N, 100_000);
//                }
//                if (random.nextBoolean()) {
//                    n = n / m * m - randomInt(1, m / 2);
//                    if (n < MIN_N) {
//                        continue;
//                    }
//                }
                    final Set<String> fails = fails(n, m, c);
                    if (known.add(fails)) {
                        System.out.format("%d %9d %5d %3d %s%n", fails.size(), n, m, c, fails);
                    }
                }
            }
        }
//        test(bestN, bestM, bestC);
    }

    public void run() {
        System.out.println("Handmade tests");
        test(1234, MIN_M, MIN_C);
        test(1700, 500, 200);
        test(12345, MAX_M, MAX_C);
        test(10000, 1000, 200);
        test(10000, 1000, 213);
        test(MIN_N, MIN_M, MIN_C);
        test(1099, 900, 200);
        test(1100, 900, 200);
        test(1101, 900, 200);
        test(1795, 900, MAX_C);
        test(8584, MAX_M, MIN_C);

        System.out.println("Property-based tests found by exaustive search");
        test(85, 4845, 169);
        test(87, 7653, 170);
        test(170, 6477, 169);
        test(172, 8962, 169);
        test(431, 500, 169);

        System.out.println("Max anti-diophantine tests");
        test(11299 * 119 - 220, 11299, 220);
        test(11298 * 220 - 11299, 11299, 220);

        System.out.println("Max diff tests");
        int m = MAX_M / MAX_C * MAX_C;
        test(MAX_C / 2 * (randomInt(MIN_N, MAX_N / MAX_C / 100) | 1), m, MAX_C);
        test(MAX_C / 2 * (randomInt(MIN_N, MAX_N / MAX_C / 2) | 1), m, MAX_C);

        System.out.println("Medium random tests");
        for (int i = 0; i < 4; i++) {
            test(
                randomInt(MIN_N, MAX_N / (int) Math.pow(100, (4 - i))),
                randomInt(MIN_M, MAX_M),
                randomInt(MIN_C, MAX_C)
            );
        }

        System.out.println("Large random tests");
        for (int i = 0; i < 3; i++) {
            test(
                randomInt(MIN_N, MAX_N / (3 - i)),
                randomInt(MIN_M, MAX_M),
                randomInt(MIN_C, MAX_C)
            );
        }

        System.out.println("Premax tests");
        test(MAX_N - 17, MIN_M + 2, MIN_C + 3);
        test(MAX_N -  7, MAX_M - 3, MAX_C - 2);

        System.out.println("Max tests");
        test(MAX_N, MIN_M, MIN_C);
        test(MAX_N, MAX_M, MAX_C);

//        for (int i = 0; i < 8; i++) {
//            new Thread(this::search).start();
//        }
    }

    public static void main(String[] args) {
        new Tests().run();
    }
}
