use std::io;
use std::io::Write;

/**************************************************

   START OF TEMPLATE CODE

*************************************************/
#[allow(unused_macros)]
macro_rules! dbg {
    ($first_val:expr, $($val:expr),+ $(,)?) => {
        eprint!("[{}:{}] {} = {:?}",
                    file!(), line!(), stringify!($first_val), &$first_val);
        ($(eprint!(", {} = {:?}", stringify!($val), &$val)),+,);
        eprintln!();
    };
    ($first_val:expr) => {
        eprintln!("[{}:{}] {} = {:?}",
                    file!(), line!(), stringify!($first_val), &$first_val);
    };
}

enum InputSource {
    Stdin,
    FromFile(Vec<String>),
}

struct Scanner {
    buffer: Vec<String>,
    input_source: InputSource,
}

impl Scanner {
    #[allow(dead_code)]
    fn new() -> Self {
        Self {
            buffer: vec![],
            input_source: InputSource::Stdin,
        }
    }

    #[allow(dead_code)]
    fn new_file(filename: &str) -> Self {
        let file = std::fs::read_to_string(filename).unwrap();
        let mut lines: Vec<String> = file.lines().map(|line| String::from(line)).collect();
        lines.reverse();
        Self {
            buffer: vec![],
            input_source: InputSource::FromFile(lines),
        }
    }

    #[allow(dead_code)]
    fn i64(&mut self) -> i64 {
        self.next::<i64>()
    }

    #[allow(dead_code)]
    fn i32(&mut self) -> i32 {
        self.next::<i32>()
    }

    #[allow(dead_code)]
    fn usize(&mut self) -> usize {
        self.next::<usize>()
    }

    #[allow(dead_code)]
    fn vec<T: std::str::FromStr>(&mut self, n: usize) -> Vec<T> {
        (0..n).map(|_| self.next::<T>()).collect()
    }

    fn parse_next_line(&mut self) -> bool {
        let mut input = String::new();
        match &mut self.input_source {
            InputSource::Stdin => {
                if std::io::stdin().read_line(&mut input).expect("Failed read") == 0 {
                    return false;
                }
            }
            InputSource::FromFile(lines) => match lines.pop() {
                Some(line) => input = line,
                None => return false,
            },
        }

        self.buffer = input.split_whitespace().rev().map(String::from).collect();
        return true;
    }

    fn next<T: std::str::FromStr>(&mut self) -> T {
        loop {
            if let Some(token) = self.buffer.pop() {
                return token.parse().ok().expect("Failed parse");
            }

            self.parse_next_line();
        }
    }

    #[allow(dead_code)]
    fn has_more_elements(&mut self) -> bool {
        loop {
            if !self.buffer.is_empty() {
                return true;
            }
            if !self.parse_next_line() {
                return false;
            }
        }
    }

    #[allow(dead_code)]
    fn string(&mut self) -> Vec<u8> {
        self.next::<String>().into_bytes()
    }
}

/**************************************************

   END OF TEMPLATE CODE

*************************************************/

struct Result {
    need_ops: usize,
    more_to_delete: usize,
}

fn rec(files: &[Vec<u8>], pos: usize, one_op_delete: usize) -> Result {
    if files.len() <= one_op_delete {
        return Result {
            need_ops: 0,
            more_to_delete: files.len(),
        };
    }
    let mut child = vec![];
    let mut i = 0;
    let mut need_ops = 0;
    while i != files.len() {
        let mut j = i;
        while j != files.len() && files[j].get(pos) == files[i].get(pos) {
            j += 1;
        }
        let rec_res = rec(&files[i..j], pos + 1, one_op_delete);
        need_ops += rec_res.need_ops;
        child.push(rec_res.more_to_delete);
        i = j;
    }
    child.sort();
    let mut sum_in_child = child.iter().sum();
    while sum_in_child > one_op_delete {
        let biggest_child = child.pop().unwrap();
        sum_in_child -= biggest_child;
        need_ops += 1;
    }
    Result {
        need_ops,
        more_to_delete: sum_in_child,
    }
}

pub fn main() {
    let stdout = io::stdout();
    let mut out = std::io::BufWriter::new(stdout.lock());
    let mut sc = Scanner::new();

    let n = sc.usize();
    let one_op_delete = sc.usize();
    let mut files = vec![];
    for _ in 0..n {
        files.push(sc.string());
    }
    files.sort();
    let res = rec(&files, 0, one_op_delete);
    let need_ops = res.need_ops + (if res.more_to_delete == 0 { 0 } else { 1 });
    writeln!(out, "{}", need_ops).unwrap();
}
