import kotlin.math.abs
import kotlin.random.Random

private const val SUBMIT = true
private const val MAX_N = 1 shl 14
private const val EPSILON_INVERSE = 100
private var n = 0
private var random = Random(566)
private fun randomPermutation() = List(n) { it }.shuffled(random)
private var queryCount = 0

private fun compare(a: Int, b: Int): Int {
	if (EPSILON_INVERSE * abs(a - b) <= maxOf(a, b)) return 0
	return if (a < b) -1 else 1
}

private fun compareRandomized(a: Int, b: Int): Int {
	val compare = compare(a, b)
	return if (compare != 0) compare else if (random.nextBoolean()) 1 else -1
}

private fun Int.countSignificantBits() = Int.SIZE_BITS - Integer.numberOfLeadingZeros(this)
private fun inversions(a: List<Int>) = a.indices.sumOf { i -> a.take(i).count { it > a[i] } }

private fun askCompare(i: Int, j: Int): Int {
	queryCount++
	if (SUBMIT) {
		println("C ${outputP[i] + 1} ${outputP[j] + 1}")
		return readLine()!!.toInt()
	}
	return compare(hidden[outputP[i]], hidden[outputP[j]])
}

private fun askSwap(i: Int, j: Int): Int {
	queryCount++
	if (SUBMIT) {
		println("S ${i + 1} ${j + 1}")
		return readLine()!!.toInt()
	}
	return 0
}

private fun IntRange.binarySearch(predicate: (Int) -> Boolean): Int {
	var (low, high) = this.first to this.last // must be false ... must be true
	while (low + 1 < high) (low + (high - low) / 2).also { if (predicate(it)) high = it else low = it }
	return high // first true
}

private lateinit var largestEqual: IntArray
private lateinit var smallestEqual: IntArray
private lateinit var hidden: IntArray
private lateinit var outputP: IntArray
val danger = mutableListOf<Int>()
val checks = mutableListOf<Pair<Int, Int>>()

private fun init() {
	fun smallestEqual(a: Int) = (a downTo 1).takeWhile { compare(it, a) == 0 }.last()
	fun largestEqual(a: Int) = (a..n).takeWhile { compare(it, a) == 0 }.last()
//	fun largestLess(x: Int) = (x + 1) * (EPSILON_INVERSE - 1) / EPSILON_INVERSE - 1
//	fun largestLess(x: Int) = smallestEqual(x) - 1
	smallestEqual = IntArray(n + 1) { if (it == 0) 0 else smallestEqual(it) }
	largestEqual = IntArray(n + 1) { largestEqual(it) }
	if (!SUBMIT) hidden = randomPermutation().map { it + 1 }.toIntArray()
	outputP = randomPermutation().toIntArray()
	queryCount = 0
	danger.clear()
	checks.clear()
	for (i in n - 2 downTo 0) {
		if (smallestEqual[i + 1] == smallestEqual[i + 2]) {
			if (largestEqual[i + 1] == largestEqual[i + 2]) {
				danger.add(i)
				continue
			}
			val j = largestEqual[i + 2] - 1
			checks.add(i to j)
		}
	}
}

private fun solveQuickSort() {
	if (SUBMIT) n = readLine()!!.toInt()
	val memo = mutableMapOf<Long, Int>()
	fun askCompareSmart(i: Int, j: Int): Int {
		if (i == j) return 0
		if (i > j) return -askCompareSmart(j, i)
		val id = i * n.toLong() + j
		return memo.computeIfAbsent(id) { askCompare(i, j) }
	}
	init()
	//	println(compareCount)
	fun quickSort(a: IntArray): List<IntArray> {
		if (a.isEmpty()) return listOf()
		if (a.size == 1) return listOf(intArrayOf(a[0]))
		val sampleSize = a.size.countSignificantBits() / 2 * 2 - 1
//		val sampleSize = if (a.size >= 256) 15 else if (a.size >= 16) 3 else  1
		val sample = a.take(sampleSize).toMutableList()
		sample.sortBy { x -> sample.sumOf { askCompareSmart(x, it) } }
		val pivot = sample[sample.size / 2]
		val groupsMap = a.groupBy { if (it == pivot) 0 else askCompareSmart(it, pivot) }
		val groups = List(3) { (groupsMap[it - 1] ?: listOf()).toIntArray() }
		return quickSort(groups[0]) + listOf(groups[1]) + quickSort(groups[2])
	}
	val indices = IntArray(n) { it }
	val groupsStack = quickSort(indices).reversed().toMutableList()
//	println(compareCount)
	val ans = mutableListOf<Int>()
	val score = IntArray(n)
	while (groupsStack.isNotEmpty()) {
		val group = groupsStack.removeLast()
		if (group.size <= 1) {
			ans.addAll(group.asList())
			continue
		}
		fun score(x: Int): Int {
			var y: Int
//			val low = maxOf(ans.size - 2 * EPSILON_INVERSE, 0)
			val low = smallestEqual[ans.size] - 1
			val high = minOf(smallestEqual[ans.size + group.size - 1], ans.size)
			y = (low..high).binarySearch { askCompareSmart(ans[it], x) == 0 } - 1
			y = minOf(y + 3, ans.lastIndex)
//			y = ans.lastIndex
			while (askCompareSmart(ans[y], x) == 0) y--
			if (askCompareSmart(ans[y - 1], x) == 0) {
				val t = ans[y - 1]; ans[y - 1] = ans[y]; ans[y] = t
				y--
			}
			return ans.lastIndex - y
		}
		for (x in group) {
			score[x] = score(x)
//			println(score[x])
		}
		val (scoreZero, scoreNonZero) = group.partition { score[it] == 0 }
		val sure = scoreNonZero.sortedBy { -score[it] }
//		println(sure.map { hidden[outputP[it]] })
		ans.addAll(sure)
		if (sure.isEmpty()) {
			ans.addAll(group.sortedBy { x -> group.sumOf { askCompareSmart(x, it) } })
		} else {
			groupsStack.add(scoreZero.toIntArray())
		}
		while (checks.isNotEmpty()) {
			val (i, j) = checks.last()
			if (j >= ans.size) break
			checks.removeLast()
			if (askCompareSmart(ans[i], ans[j]) == 0) {
				val t = ans[i]; ans[i] = ans[i + 1]; ans[i + 1] = t
			}
		}
	}

	if (!SUBMIT) {
//		println(compareCount)
		val cheat = ans.map { hidden[outputP[it]] }
//		println(cheat.takeLast(120))
		cheat.zipWithNext { a, b -> if (a + 1 != b) println("$a $b") }
	}

	val p = IntArray(n)
	for (i in ans.indices) {
		p[outputP[ans[i]]] = i
	}
	for (i in ans.indices) {
		while (p[i] != i) {
			val pi = p[i]
			if (askSwap(i, pi) == 1) return
			val t = p[i]; p[i] = p[pi]; p[pi] = t
		}
	}
	repeat(566) {
		val (i, j) = if (danger.isEmpty()) 0 to 0 else danger.random(random).let { it to it + 1 }
		if (askSwap(i, j) == 1) return
	}
}

@Deprecated("")
private fun research() {
	n = MAX_N
	n = 16301
//	(1..n).zipWithNext { i, j ->
//		if (smallestEqual(i) == smallestEqual(j) && largestEqual(i) == largestEqual(j)) println("$i $j")
//		if (largestLess(i) != smallestEqual(i) - 1) println(i)
//	}
//	val p = randomPermutation().map { it + 1 }.toMutableList()
//	compareCount = 0
//	println(p.takeLast(50))
//	println(inversions(p))
//	println(compareCount)
//	p.sortWith(::compareRandomized)
//	println(p.takeLast(50))
//	println(inversions(p))
//	println(compareCount)
	repeat(1000) {
		val seed = it
		random = Random(seed)
		solveQuickSort()
		println("$seed $queryCount")
	}

}

fun main() {
	if (SUBMIT) solveQuickSort() else research()
}
