#include "testlib.h"
#include <cassert>
#include <functional>

using namespace std;

struct vertex {
	int white;
	int black;
};

struct test {
	vector<vertex> a;
};

test gen(int n, function<int(int)> d) {
	vector<vertex> a(n);
	for (int i = 1; i < n; i++) {
		int to = d(i);
		int color = rnd.next(0, 1);
		if (color == 0) {
			a[to].white++;
			a[i].white++;
		} else {
			a[to].black++;
			a[i].black++;
		}
	}
	shuffle(a.begin(), a.end());
	return {a};
}
test genPath(int n) {
	return gen(n, [](int x) { return x - 1; });
}

test genBinary(int n) {
	return gen(n, [](int x) { return (x - 1) / 2; });
}


test genStar(int n) {
	return gen(n, [](int) { return 0; });
}

test genRandom(int n, double rp) {
	return gen(n, [rp](int x) { return rnd.next(0, max(1, (int) (rp * (x - 1))));});
}

vector<string> TYPES = {"path", "binary", "star", "random"};

int main(int argc, char **argv) {
	registerGen(argc, argv, 1);
	int sumN = opt<int>("sumN");
	int maxN = has_opt("n") ? opt<int>("n") : 0;
	bool make_max = opt<bool>("max");
	string type = opt<string>("type");
	double rp = has_opt("rp") ? opt<double>("rp") : 1.0;
	vector<test> tests;
	int currentSum = 0;
	while (currentSum < sumN) {
		int n = make_max ? sumN : max(1, min(rnd.next(maxN / 2, maxN), sumN - currentSum));
		string op = type == "any" ? TYPES[rnd.next(0, (int) TYPES.size() - 1)] : type;
		if (op == "path") {
			tests.push_back(genPath(n));
		} else if (op == "binary") {
			tests.push_back(genBinary(n));
		} else if (op == "star") {
			tests.push_back(genStar(n));
		} else if (op == "random") {
			tests.push_back(genRandom(n, rp));
		} else assert(false);
		currentSum += n;
	}
	cout << tests.size() << '\n';
	for (auto &e : tests) {
		cout << e.a.size() << '\n';
		for (auto &v : e.a) {
			cout << v.white << ' ' << v.black << '\n';
		}
	}
}
