
private class Vertex(var white: Int, var black: Int, val id: Int) {
    override fun toString() = "{$white, $black, $id}"
}

private class Edge(val v: Vertex, val u: Vertex, val color: Char)

private fun solve(a: Array<Vertex>): List<Edge>? {
    val n = a.size
    if (n == 1) {
        return listOf()
    }
    if (a.any { it.white == 0 && it.black == 0 }) {
        return null
    }
    val sumWhite = a.sumOf { it.white.toLong() }
    val sumBlack = a.sumOf { it.black.toLong() }
    val nonZeroWhites = a.count { it.white != 0 }
    if (!(sumWhite % 2 == 0L && sumBlack % 2 == 0L && sumWhite + sumBlack == 2L * (n - 1) && (nonZeroWhites == 0 || sumWhite <= 2 * (nonZeroWhites - 1)))) {
        return null
    }
    val ans = mutableListOf<Edge>()
    val leaves = a.filter { it.white + it.black == 1 }.toMutableList()
    val bestBlack = a.filter { it.white + it.black > 1 }.toSortedSet(compareBy<Vertex> { it.black }.thenBy { it.id })
    val bestWhite = a.filter { it.white + it.black > 1 }.toSortedSet(compareBy<Vertex> { it.white }.thenBy { it.id })
    while (bestBlack.isNotEmpty() || bestWhite.isNotEmpty()) {
        val v = leaves.removeLast()
        bestBlack.remove(v)
        bestWhite.remove(v)
        val u = when {
            v.black != 0 -> {
                if (bestBlack.isEmpty()) {
                    return null
                }
                val u = bestBlack.last()
                if (u.black == 0) {
                    return null
                }
                bestBlack.remove(u)
                bestWhite.remove(u)
                u.black--
                ans.add(Edge(u, v, 'B'))
                u
            }
            else -> {
                if (bestWhite.isEmpty()) {
                    return null
                }
                val u = bestWhite.last()
                if (u.white == 0) {
                    return null
                }
                bestBlack.remove(u)
                bestWhite.remove(u)
                u.white--
                ans.add(Edge(u, v, 'W'))
                u
            }
        }
        if (u.black + u.white == 1) {
            leaves.add(u)
        } else {
            bestBlack.add(u)
            bestWhite.add(u)
        }
    }
    assert(leaves.size == 2)
    val v = leaves.removeLast()
    val u = leaves.removeLast()
    if (v.white == 1 && u.white == 1) {
        ans.add(Edge(v, u, 'W'))
    } else if (v.black == 1 && u.black == 1) {
        ans.add(Edge(v, u, 'B'))
    } else {
        return null
    }
    assert(ans.size == n - 1)
    return ans
}

fun main() {
    val t = readInt()
    repeat(t) {
        val n = readInt()
        val a = Array(n) { id ->
            val (w, b) = readInts()
            Vertex(w, b, id)
        }
        val answer = solve(a)
        if (answer == null) {
            println("No")
        } else {
            println("Yes")
            for (x in answer) {
                println("${x.v.id + 1} ${x.u.id + 1} ${x.color}")
            }
        }
    }
}

private fun readInts() = readWords().map { it.toInt() }
private fun readLongs() = readWords().map { it.toLong() }
private fun readWords() = readLn().split(" ")
private fun readInt() = readLn().toInt()
private fun readLong() = readLn().toLong()
private fun readLn() = readLine()!!
